from nautobot.dcim.choices import CableStatusChoices
from nautobot.extras.plugins import PluginTemplateExtension

from .models import MeasurementLog


class DeviceBulkConnect(PluginTemplateExtension):
    model = 'dcim.cable'

    def buttons(self):
        cable = self.context['object']
        log = None
        maybe_log = MeasurementLog.objects.filter(cable=cable)
        if maybe_log.exists():
            log = maybe_log.first().link
        return self.render('nautobot_cable_utils/inc/buttons.html', {
            'cable': cable,
            'cable_planned': cable.status.slug == CableStatusChoices.STATUS_PLANNED,
            'log': log,
        })


template_extensions = [DeviceBulkConnect]



import django_filters
from django.db.models import Q

from nautobot.utilities.choices import ColorChoices
from nautobot.utilities.filters import BaseFilterSet

from .models import CableTemplate


class CableTemplateFilterSet(BaseFilterSet):
    q = django_filters.CharFilter(
        method='search',
        label='Search',
    )
    color = django_filters.MultipleChoiceFilter(
        choices=ColorChoices
    )

    class Meta:
        model = CableTemplate
        fields = ['cable_number', 'type', 'color']

    def search(self, queryset, name, value):
        if not value.strip():
            return queryset
        qs_filter = (
            Q(cable_number__icontains=value) |
            Q(label__icontains=value)
        )
        return queryset.filter(qs_filter)
